﻿/* IFlowControllableBranch.cs
 * 
 * Copyright (C) 2018 E.Togashi
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

namespace Popolo.HVAC.Circuit.ControllableFlowSolver
{
  /// <summary>抵抗調整によって流量制御可能な可変流量回路</summary>
  public interface IFlowControllableBranch
  {
    /// <summary>合成抵抗が変化したか否か</summary>
    bool HasTotalResistanceChanged { get; }

    /// <summary>回路の合計流量[m3/s]を取得する</summary>
    double TotalFlowRate { get; }

    /// <summary>回路の合計設定流量[m3/s]を取得する</summary>
    /// <returns>回路の合計設定流量[m3/s]</returns>
    double GetTotalFlowSetPoint();

    /// <summary>必要最低差圧[kPa]を取得する</summary>
    /// <returns>必要最低差圧[kPa]</returns>
    double GetMinimumPressure();

    /// <summary>回路全体の合成抵抗[kPa/(m3/s)^2]を取得する</summary>
    /// <returns>回路全体の合成抵抗[kPa/(m3/s)^2]</returns>
    double GetTotalResistance();

    /// <summary>差圧にもとづいて流量を調整する</summary>
    /// <param name="pressure">差圧[kPa]</param>
    void ControlFlowRate(double pressure);
  }
}
